@@ -1,6 +1,6 @@
 ################################################################################
 ##
-## $Id: AllGenerics.R 1227 2007-10-01 18:50:15Z enos $
+## $Id: AllGenerics.R 1300 2008-08-27 21:01:11Z zhao $
 ##
 ## Generic functions for the backtest class
 ##
@@ -22,6 +22,9 @@ if(!isGeneric("means"))
 if(!isGeneric("counts"))
   setGeneric("counts", function(object, ...) standardGeneric("counts"))
 
+if(!isGeneric("totalCounts"))
+  setGeneric("totalCounts", function(object, ...) standardGeneric("totalCounts"))
+
 if(!isGeneric("marginals"))
   setGeneric("marginals", function(object, ...) standardGeneric("marginals"))
 
